syncjoberror

package
v8.19.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2026 License: Apache-2.0 Imports: 12 Imported by: 2

Documentation

Overview

Set a connector sync job error. Set the `error` field for a connector sync job and set its `status` to `error`.

To sync data using self-managed connectors, you need to deploy the Elastic connector service on your own infrastructure. This service runs automatically on Elastic Cloud for Elastic managed connectors.

Index

Constants

This section is empty.

Variables

var ErrBuildPath = errors.New("cannot build path, check for missing path parameters")

ErrBuildPath is returned in case of missing parameters within the build of the request.

Functions

This section is empty.

Types

type NewSyncJobError

type NewSyncJobError func(connectorsyncjobid string) *SyncJobError

NewSyncJobError type alias for index.

func NewSyncJobErrorFunc

func NewSyncJobErrorFunc(tp elastictransport.Interface) NewSyncJobError

NewSyncJobErrorFunc returns a new instance of SyncJobError with the provided transport. Used in the index of the library this allows to retrieve every apis in once place.

type Request

type Request struct {
	// Error The error for the connector sync job error field.
	Error string `json:"error"`
}

Request holds the request body struct for the package syncjoberror

https://github.com/elastic/elasticsearch-specification/blob/470b4b9aaaa25cae633ec690e54b725c6fc939c7/specification/connector/sync_job_error/SyncJobErrorRequest.ts#L23-L52

func NewRequest

func NewRequest() *Request

NewRequest returns a Request

func (*Request) FromJSON

func (r *Request) FromJSON(data string) (*Request, error)

FromJSON allows to load an arbitrary json into the request structure

type Response

type Response struct {
}

Response holds the response body struct for the package syncjoberror

https://github.com/elastic/elasticsearch-specification/blob/470b4b9aaaa25cae633ec690e54b725c6fc939c7/specification/connector/sync_job_error/SyncJobErrorResponse.ts#L20-L22

func NewResponse

func NewResponse() *Response

NewResponse returns a Response

type SyncJobError

type SyncJobError struct {
	// contains filtered or unexported fields
}

func New

Set a connector sync job error. Set the `error` field for a connector sync job and set its `status` to `error`.

To sync data using self-managed connectors, you need to deploy the Elastic connector service on your own infrastructure. This service runs automatically on Elastic Cloud for Elastic managed connectors.

https://www.elastic.co/guide/en/elasticsearch/reference/current/set-connector-sync-job-error-api.html

func (SyncJobError) Do

func (r SyncJobError) Do(providedCtx context.Context) (*Response, error)

Do runs the request through the transport, handle the response and returns a syncjoberror.Response

func (*SyncJobError) Error

func (r *SyncJobError) Error(error string) *SyncJobError

Error The error for the connector sync job error field. API name: error

func (*SyncJobError) ErrorTrace

func (r *SyncJobError) ErrorTrace(errortrace bool) *SyncJobError

ErrorTrace When set to `true` Elasticsearch will include the full stack trace of errors when they occur. API name: error_trace

func (*SyncJobError) FilterPath

func (r *SyncJobError) FilterPath(filterpaths ...string) *SyncJobError

FilterPath Comma-separated list of filters in dot notation which reduce the response returned by Elasticsearch. API name: filter_path

func (*SyncJobError) Header

func (r *SyncJobError) Header(key, value string) *SyncJobError

Header set a key, value pair in the SyncJobError headers map.

func (*SyncJobError) HttpRequest

func (r *SyncJobError) HttpRequest(ctx context.Context) (*http.Request, error)

HttpRequest returns the http.Request object built from the given parameters.

func (*SyncJobError) Human

func (r *SyncJobError) Human(human bool) *SyncJobError

Human When set to `true` will return statistics in a format suitable for humans. For example `"exists_time": "1h"` for humans and `"eixsts_time_in_millis": 3600000` for computers. When disabled the human readable values will be omitted. This makes sense for responses being consumed only by machines. API name: human

func (SyncJobError) Perform

func (r SyncJobError) Perform(providedCtx context.Context) (*http.Response, error)

Perform runs the http.Request through the provided transport and returns an http.Response.

func (*SyncJobError) Pretty

func (r *SyncJobError) Pretty(pretty bool) *SyncJobError

Pretty If set to `true` the returned JSON will be "pretty-formatted". Only use this option for debugging only. API name: pretty

func (*SyncJobError) Raw

func (r *SyncJobError) Raw(raw io.Reader) *SyncJobError

Raw takes a json payload as input which is then passed to the http.Request If specified Raw takes precedence on Request method.

func (*SyncJobError) Request

func (r *SyncJobError) Request(req *Request) *SyncJobError

Request allows to set the request property with the appropriate payload.

Jump to