updateerror

package
v8.17.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2025 License: Apache-2.0 Imports: 13 Imported by: 2

Documentation

Overview

Update the connector error field.

Set the error field for the connector. If the error provided in the request body is non-null, the connector’s status is updated to error. Otherwise, if the error is reset to null, the connector status is updated to connected.

Index

Constants

This section is empty.

Variables

var ErrBuildPath = errors.New("cannot build path, check for missing path parameters")

ErrBuildPath is returned in case of missing parameters within the build of the request.

Functions

This section is empty.

Types

type NewUpdateError

type NewUpdateError func(connectorid string) *UpdateError

NewUpdateError type alias for index.

func NewUpdateErrorFunc

func NewUpdateErrorFunc(tp elastictransport.Interface) NewUpdateError

NewUpdateErrorFunc returns a new instance of UpdateError with the provided transport. Used in the index of the library this allows to retrieve every apis in once place.

type Request

type Request struct {
	Error any `json:"error"`
}

Request holds the request body struct for the package updateerror

https://github.com/elastic/elasticsearch-specification/blob/2f823ff6fcaa7f3f0f9b990dc90512d8901e5d64/specification/connector/update_error/ConnectorUpdateErrorRequest.ts#L23-L48

func NewRequest

func NewRequest() *Request

NewRequest returns a Request

func (*Request) FromJSON

func (r *Request) FromJSON(data string) (*Request, error)

FromJSON allows to load an arbitrary json into the request structure

func (*Request) UnmarshalJSON

func (s *Request) UnmarshalJSON(data []byte) error

type Response

type Response struct {
	Result result.Result `json:"result"`
}

Response holds the response body struct for the package updateerror

https://github.com/elastic/elasticsearch-specification/blob/2f823ff6fcaa7f3f0f9b990dc90512d8901e5d64/specification/connector/update_error/ConnectorUpdateErrorResponse.ts#L22-L26

func NewResponse

func NewResponse() *Response

NewResponse returns a Response

type UpdateError

type UpdateError struct {
	// contains filtered or unexported fields
}

func New

Update the connector error field.

Set the error field for the connector. If the error provided in the request body is non-null, the connector’s status is updated to error. Otherwise, if the error is reset to null, the connector status is updated to connected.

https://www.elastic.co/guide/en/elasticsearch/reference/current/update-connector-error-api.html

func (UpdateError) Do

func (r UpdateError) Do(providedCtx context.Context) (*Response, error)

Do runs the request through the transport, handle the response and returns a updateerror.Response

func (*UpdateError) Error

func (r *UpdateError) Error(error any) *UpdateError

API name: error

func (*UpdateError) ErrorTrace

func (r *UpdateError) ErrorTrace(errortrace bool) *UpdateError

ErrorTrace When set to `true` Elasticsearch will include the full stack trace of errors when they occur. API name: error_trace

func (*UpdateError) FilterPath

func (r *UpdateError) FilterPath(filterpaths ...string) *UpdateError

FilterPath Comma-separated list of filters in dot notation which reduce the response returned by Elasticsearch. API name: filter_path

func (*UpdateError) Header

func (r *UpdateError) Header(key, value string) *UpdateError

Header set a key, value pair in the UpdateError headers map.

func (*UpdateError) HttpRequest

func (r *UpdateError) HttpRequest(ctx context.Context) (*http.Request, error)

HttpRequest returns the http.Request object built from the given parameters.

func (*UpdateError) Human

func (r *UpdateError) Human(human bool) *UpdateError

Human When set to `true` will return statistics in a format suitable for humans. For example `"exists_time": "1h"` for humans and `"eixsts_time_in_millis": 3600000` for computers. When disabled the human readable values will be omitted. This makes sense for responses being consumed only by machines. API name: human

func (UpdateError) Perform

func (r UpdateError) Perform(providedCtx context.Context) (*http.Response, error)

Perform runs the http.Request through the provided transport and returns an http.Response.

func (*UpdateError) Pretty

func (r *UpdateError) Pretty(pretty bool) *UpdateError

Pretty If set to `true` the returned JSON will be "pretty-formatted". Only use this option for debugging only. API name: pretty

func (*UpdateError) Raw

func (r *UpdateError) Raw(raw io.Reader) *UpdateError

Raw takes a json payload as input which is then passed to the http.Request If specified Raw takes precedence on Request method.

func (*UpdateError) Request

func (r *UpdateError) Request(req *Request) *UpdateError

Request allows to set the request property with the appropriate payload.

Jump to