updatebyqueryrethrottle

package
v8.10.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 13, 2023 License: Apache-2.0 Imports: 12 Imported by: 6

Documentation

Overview

Changes the number of requests per second for a particular Update By Query operation.

Index

Constants

This section is empty.

Variables

var ErrBuildPath = errors.New("cannot build path, check for missing path parameters")

ErrBuildPath is returned in case of missing parameters within the build of the request.

Functions

This section is empty.

Types

type NewUpdateByQueryRethrottle

type NewUpdateByQueryRethrottle func(taskid string) *UpdateByQueryRethrottle

NewUpdateByQueryRethrottle type alias for index.

func NewUpdateByQueryRethrottleFunc

func NewUpdateByQueryRethrottleFunc(tp elastictransport.Interface) NewUpdateByQueryRethrottle

NewUpdateByQueryRethrottleFunc returns a new instance of UpdateByQueryRethrottle with the provided transport. Used in the index of the library this allows to retrieve every apis in once place.

type Response added in v8.7.0

type Response struct {
	Nodes map[string]types.UpdateByQueryRethrottleNode `json:"nodes"`
}

func NewResponse added in v8.7.0

func NewResponse() *Response

NewResponse returns a Response

type UpdateByQueryRethrottle

type UpdateByQueryRethrottle struct {
	// contains filtered or unexported fields
}

func New

Changes the number of requests per second for a particular Update By Query operation.

https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-update-by-query.html

func (UpdateByQueryRethrottle) Do

Do runs the request through the transport, handle the response and returns a updatebyqueryrethrottle.Response

func (*UpdateByQueryRethrottle) Header

Header set a key, value pair in the UpdateByQueryRethrottle headers map.

func (*UpdateByQueryRethrottle) HttpRequest

func (r *UpdateByQueryRethrottle) HttpRequest(ctx context.Context) (*http.Request, error)

HttpRequest returns the http.Request object built from the given parameters.

func (UpdateByQueryRethrottle) IsSuccess

func (r UpdateByQueryRethrottle) IsSuccess(ctx context.Context) (bool, error)

IsSuccess allows to run a query with a context and retrieve the result as a boolean. This only exists for endpoints without a request payload and allows for quick control flow.

func (UpdateByQueryRethrottle) Perform added in v8.7.0

Perform runs the http.Request through the provided transport and returns an http.Response.

func (*UpdateByQueryRethrottle) RequestsPerSecond

func (r *UpdateByQueryRethrottle) RequestsPerSecond(requestspersecond string) *UpdateByQueryRethrottle

RequestsPerSecond The throttle to set on this request in floating sub-requests per second. -1 means set no throttle. API name: requests_per_second

func (*UpdateByQueryRethrottle) TaskId

TaskId The task id to rethrottle API Name: taskid

Jump to