Documentation
¶
Overview ¶
Update the connector filtering.
Update the draft filtering configuration of a connector and marks the draft validation state as edited. The filtering draft is activated once validated by the running Elastic connector service. The filtering property is used to configure sync rules (both basic and advanced) for a connector.
Index ¶
- Variables
- type NewUpdateFiltering
- type Request
- type Response
- type UpdateFiltering
- func (r *UpdateFiltering) AdvancedSnippet(advancedsnippet types.FilteringAdvancedSnippetVariant) *UpdateFiltering
- func (r UpdateFiltering) Do(providedCtx context.Context) (*Response, error)
- func (r *UpdateFiltering) ErrorTrace(errortrace bool) *UpdateFiltering
- func (r *UpdateFiltering) FilterPath(filterpaths ...string) *UpdateFiltering
- func (r *UpdateFiltering) Filtering(filterings ...types.FilteringConfigVariant) *UpdateFiltering
- func (r *UpdateFiltering) Header(key, value string) *UpdateFiltering
- func (r *UpdateFiltering) HttpRequest(ctx context.Context) (*http.Request, error)
- func (r *UpdateFiltering) Human(human bool) *UpdateFiltering
- func (r UpdateFiltering) Perform(providedCtx context.Context) (*http.Response, error)
- func (r *UpdateFiltering) Pretty(pretty bool) *UpdateFiltering
- func (r *UpdateFiltering) Raw(raw io.Reader) *UpdateFiltering
- func (r *UpdateFiltering) Request(req *Request) *UpdateFiltering
- func (r *UpdateFiltering) Rules(rules ...types.FilteringRuleVariant) *UpdateFiltering
Constants ¶
This section is empty.
Variables ¶
var ErrBuildPath = errors.New("cannot build path, check for missing path parameters")
ErrBuildPath is returned in case of missing parameters within the build of the request.
Functions ¶
This section is empty.
Types ¶
type NewUpdateFiltering ¶
type NewUpdateFiltering func(connectorid string) *UpdateFiltering
NewUpdateFiltering type alias for index.
func NewUpdateFilteringFunc ¶
func NewUpdateFilteringFunc(tp elastictransport.Interface) NewUpdateFiltering
NewUpdateFilteringFunc returns a new instance of UpdateFiltering with the provided transport. Used in the index of the library this allows to retrieve every apis in once place.
type Request ¶
type Request struct {
AdvancedSnippet *types.FilteringAdvancedSnippet `json:"advanced_snippet,omitempty"`
Filtering []types.FilteringConfig `json:"filtering,omitempty"`
Rules []types.FilteringRule `json:"rules,omitempty"`
}
Request holds the request body struct for the package updatefiltering
type UpdateFiltering ¶
type UpdateFiltering struct {
// contains filtered or unexported fields
}
func New ¶
func New(tp elastictransport.Interface) *UpdateFiltering
Update the connector filtering.
Update the draft filtering configuration of a connector and marks the draft validation state as edited. The filtering draft is activated once validated by the running Elastic connector service. The filtering property is used to configure sync rules (both basic and advanced) for a connector.
https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-connector-update-filtering
func (*UpdateFiltering) AdvancedSnippet ¶
func (r *UpdateFiltering) AdvancedSnippet(advancedsnippet types.FilteringAdvancedSnippetVariant) *UpdateFiltering
API name: advanced_snippet
func (UpdateFiltering) Do ¶
func (r UpdateFiltering) Do(providedCtx context.Context) (*Response, error)
Do runs the request through the transport, handle the response and returns a updatefiltering.Response
func (*UpdateFiltering) ErrorTrace ¶
func (r *UpdateFiltering) ErrorTrace(errortrace bool) *UpdateFiltering
ErrorTrace When set to `true` Elasticsearch will include the full stack trace of errors when they occur. API name: error_trace
func (*UpdateFiltering) FilterPath ¶
func (r *UpdateFiltering) FilterPath(filterpaths ...string) *UpdateFiltering
FilterPath Comma-separated list of filters in dot notation which reduce the response returned by Elasticsearch. API name: filter_path
func (*UpdateFiltering) Filtering ¶
func (r *UpdateFiltering) Filtering(filterings ...types.FilteringConfigVariant) *UpdateFiltering
API name: filtering
func (*UpdateFiltering) Header ¶
func (r *UpdateFiltering) Header(key, value string) *UpdateFiltering
Header set a key, value pair in the UpdateFiltering headers map.
func (*UpdateFiltering) HttpRequest ¶
HttpRequest returns the http.Request object built from the given parameters.
func (*UpdateFiltering) Human ¶
func (r *UpdateFiltering) Human(human bool) *UpdateFiltering
Human When set to `true` will return statistics in a format suitable for humans. For example `"exists_time": "1h"` for humans and `"exists_time_in_millis": 3600000` for computers. When disabled the human readable values will be omitted. This makes sense for responses being consumed only by machines. API name: human
func (UpdateFiltering) Perform ¶
Perform runs the http.Request through the provided transport and returns an http.Response.
func (*UpdateFiltering) Pretty ¶
func (r *UpdateFiltering) Pretty(pretty bool) *UpdateFiltering
Pretty If set to `true` the returned JSON will be "pretty-formatted". Only use this option for debugging only. API name: pretty
func (*UpdateFiltering) Raw ¶
func (r *UpdateFiltering) Raw(raw io.Reader) *UpdateFiltering
Raw takes a json payload as input which is then passed to the http.Request If specified Raw takes precedence on Request method.
func (*UpdateFiltering) Request ¶
func (r *UpdateFiltering) Request(req *Request) *UpdateFiltering
Request allows to set the request property with the appropriate payload.
func (*UpdateFiltering) Rules ¶
func (r *UpdateFiltering) Rules(rules ...types.FilteringRuleVariant) *UpdateFiltering
API name: rules